summaryrefslogtreecommitdiff
path: root/dmake/unix/runargv.c
diff options
context:
space:
mode:
Diffstat (limited to 'dmake/unix/runargv.c')
-rw-r--r--dmake/unix/runargv.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/dmake/unix/runargv.c b/dmake/unix/runargv.c
index 4e87862125ae..d4c0a21a5363 100644
--- a/dmake/unix/runargv.c
+++ b/dmake/unix/runargv.c
@@ -577,7 +577,7 @@ char **cmd; /* Simulate a reference to *cmd. */
/* Really spawn or fork a child. */
#if defined( USE_SPAWN )
/* As no other childs are started while the output is redirected this
* is save. */
if( Is_exec_shell ) {
/* Add error checking? */
@@ -781,7 +781,7 @@ int pqid;
return 0;
} else {
Fatal( "dmake was interrupted or a child terminated. "
- "Stopping all childs ..." );
+ "Stopping all children ..." );
}
} else {
/* The child we were waiting for is missing or no child is
@@ -803,7 +803,7 @@ int pqid;
}
_proc_cnt = 0;
}
/* The pid we were waiting for or any of the remaining childs
* (pid == -1) is missing. This should not happen and means
* that the process got lost or was treated elsewhere. */
Fatal( "Internal Error: Child is missing but still listed in _procs[x] %d: %s\n"
@@ -577,7 +577,7 @@ char **cmd; /* Simulate a reference to *cmd. */
/* Really spawn or fork a child. */
#if defined( USE_SPAWN )
- /* As no other childs are started while the output is redirected this
+ /* As no other children are started while the output is redirected this
* is save. */
if( Is_exec_shell ) {
@@ -803,7 +803,7 @@ int pqid;
_proc_cnt = 0;
}
- /* The pid we were waiting for or any of the remaining childs
+ /* The pid we were waiting for or any of the remaining children
* (pid == -1) is missing. This should not happen and means
* that the process got lost or was treated elsewhere. */